==> advanced_quotes-1.0.tar.gz: advanced_quotes-1.0/README.md <==
<div align="center">
  <h1>advanced_quotes</h1>
  <p>Your all-access pass to the world's largest quotations database. Random , daily quotes , over 40 thousand authors, various topics. Inside your comfy python development environment!</p>

  <a class="license" href="https://pypi.org/project/advanced_quotes/">
    <img src="https://img.shields.io/pypi/l/advanced_quotes?label=License&style=flat-square">
  </a>

  <a class="downloads" href="https://pypi.org/project/advanced_quotes/">
    <img src="https://img.shields.io/pypi/dw/advanced_quotes?label=Downloads&style=flat-square">
  </a>

  <a class="status" href="https://pypi.org/project/advanced_quotes/">
    <img src="https://img.shields.io/pypi/status/advanced_quotes?label=Status&style=flat-square">
  </a>
</div>

## Features
- Retrieve random quotes.
- Retrieve daily quotes.
- View a specific author's full set of quotes and info.
- View a specific topic's full set of quotes .
- A topic/author index so you can search for them.
- Well documented with examples.

**Note**:  This is heavily based on classes, you must be familiar with those.

### Getting started
- Download the module using pip :

      $ pip install advanced_quotes

    **Note**: This may differentiate depending on your use case
- Import the module, use whatever you need

### Documentation
This module is fully documented on the dedicated [website](https://advanced-quotes.mahdios.gq).

### Copyright

<div align="center">
<i>Copyright (c) 2020 Copyright Holder All Rights Reserved.<br>
Data provided by <a href="https://www.brainyquote.com/">BrainyQuote</a>

</div>

==> advanced_quotes-1.0.1.tar.gz: advanced_quotes-1.0.1/README.md <==
<div align="center">
  <h1>advanced_quotes</h1>
  <p>Your all-access pass to the world's largest quotations database. Random , daily quotes , over 40 thousand authors, various topics. Inside your comfy python development environment!</p>

  <a class="license" href="https://pypi.org/project/advanced_quotes/">
    <img src="https://img.shields.io/pypi/l/advanced_quotes?label=License&style=flat-square">
  </a>

  <a class="downloads" href="https://pypi.org/project/advanced_quotes/">
    <img src="https://img.shields.io/pypi/dw/advanced_quotes?label=Downloads&style=flat-square">
  </a>

  <a class="status" href="https://pypi.org/project/advanced_quotes/">
    <img src="https://img.shields.io/pypi/status/advanced_quotes?label=Status&style=flat-square">
  </a>
</div>

## Features
- Retrieve random quotes.
- Retrieve daily quotes.
- View a specific author's full set of quotes and info.
- View a specific topic's full set of quotes .
- A topic/author index so you can search for them.
- Well documented with examples.

**Note**:  This is heavily based on classes, you must be familiar with those.

### Getting started
- Download the module using pip :

      $ pip install advanced-quotes

    **Note**: This may differentiate depending on your use case
- Import the module, use whatever you need. Also, you'll be accessing the module using **advanced_quotes** instead of **advanced-quotes**

### Documentation
This module is fully documented on the dedicated [website](https://advanced-quotes.mahdios.gq).

### Copyright

<div align="center">
<i>Copyright (c) 2020 Copyright Holder All Rights Reserved.<br>
Data provided by <a href="https://www.brainyquote.com/">BrainyQuote</a>

</div>
